==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/ru.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ru.php,v 1.0 2002/06/26 11:05:32
// Translated by Voldar (voldar@quality.s2.ru)

$charset                = 'cp1251';
$text['title']          = ' ';

$text['vitals']         = ' ';
$text['hostname']       = ' ';
$text['ip']             = ' IP';
$text['kversion']       = ' ';
$text['dversion']       = 'Distro Name';
$text['uptime']         = ' ';
$text['users']          = '  ';
$text['loadavg']        = ' ';

$text['hardware']       = ' ';
$text['numcpu']         = '';
$text['cpumodel']       = '';
$text['cpuspeed']       = '  MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = ' ';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = ' PCI';
$text['ide']            = ' IDE';
$text['scsi']           = ' SCSI';
$text['usb']            = ' USB';

$text['netusage']       = ' ';
$text['device']         = '';
$text['received']       = '';
$text['sent']           = '';
$text['errors']         = '';

$text['connections']    = '  ';

$text['memusage']       = ' ';
$text['phymem']         = ' ';
$text['swap']           = ' ';

$text['fs']             = '  ';
$text['mount']          = ' ';
$text['partition']      = '';

$text['percent']        = ' ';
$text['type']           = '';
$text['free']           = '';
$text['used']           = '';
$text['size']           = '';
$text['totals']         = '';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = '';

$text['capacity']       = '';

$text['template']       = '';
$text['language']       = '';
$text['submit']         = '';
$text['created']        = '';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = '';
$text['hours']          = 'hours';
$text['minutes']        = 'minutes';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= '- Kernel + applications';
$text['buffers']	= '- Buffers';
$text['cached']		= '- Cached';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/ru.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: ru.php,v 1.0 2002/06/26 11:05:32
// Translated by Voldar (voldar@quality.s2.ru)

$charset                = 'cp1251';
$text['title']          = ' ';

$text['vitals']         = ' ';
$text['hostname']       = ' ';
$text['ip']             = ' IP';
$text['kversion']       = ' ';
$text['dversion']       = 'Distro Name';
$text['uptime']         = ' ';
$text['users']          = '  ';
$text['loadavg']        = ' ';

$text['hardware']       = ' ';
$text['numcpu']         = '';
$text['cpumodel']       = '';
$text['cpuspeed']       = '  MHz';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = ' ';
$text['bogomips']       = 'System Bogomips';

$text['pci']            = ' PCI';
$text['ide']            = ' IDE';
$text['scsi']           = ' SCSI';
$text['usb']            = ' USB';

$text['netusage']       = ' ';
$text['device']         = '';
$text['received']       = '';
$text['sent']           = '';
$text['errors']         = '';

$text['connections']    = '  ';

$text['memusage']       = ' ';
$text['phymem']         = ' ';
$text['swap']           = ' ';

$text['fs']             = '  ';
$text['mount']          = ' ';
$text['partition']      = '';

$text['percent']        = ' ';
$text['type']           = '';
$text['free']           = '';
$text['used']           = '';
$text['size']           = '';
$text['totals']         = '';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = '';

$text['capacity']       = '';

$text['template']       = '';
$text['language']       = '';
$text['submit']         = '';
$text['created']        = '';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %I:%M %p';

$text['days']           = '';
$text['hours']          = 'hours';
$text['minutes']        = 'minutes';

$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']		= 'Kernel + applications';
$text['buffers']	= 'Buffers';
$text['cached']		= 'Cached';

?>
